;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x59c207aa6ca5d298397fd9fa2ace12c1 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x126739c44707ae5f9558e217f556e6ec . "./code.cg2js/cg-drag-and-drop.fasl")
(#xb031e97d63f63875a30fae407e92c52b . "./code.cg2js/cg-toolbar.fasl")
(#x599d25dcb3c351efdb24a6fec8c25368 . "./code.cg2js/cg-chart-or-plot.fasl")
(#x4a4c71b09188c4cb42620a31bb70f0e3 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#xc71cf0d767e50717a623472962486849 . "./code.cg2js/cg-class-grid.fasl")
(#xb71c572504d8c67c533d9685710d9013 . "./code.cg2js/cg-tray.fasl")
(#xc2db502f219bf349aad367473af3a956 . "./code.cg2js/cg-gesture-emulation.fasl")
(#x177803bb59d5b59c517bfae2bbc82a69 . "./code.cg2js/cg-class-support.fasl")
(#xb04937fcb1804073b65829df6f489820 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#xd24b645f6a114644ab4bcd8b469ef613 . "./code.cg2js/cg-dropping-outline.fasl")
(#xda243e56f2cae9258ccdc3c8e1c91364 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x3094f8a3b4e7a374a05a8f65b68307f4 . "./code.cg2js/cg-choice-list.fasl")
(#x447f7139de8965ac109044dd641a4b3e . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x1f7ad0412d66dd78f2e020394bf9ad83 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x377c43f9679aee2cc2779afeac4cdcf5 . "./code.cg2js/cg-timer.fasl")
(#x1c47d4043d8a0884eb8d454e2dbf4b2a . "./code.cg2js/cg-directory-dialog.fasl")
(#x50dbb808aa550b664533e4505bcbc045 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x219573d4be9269364e7d3182dacc94eb . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x61c8904d053fc9ca8e55652ec872b9fc . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x0b0277eb20f2f4238879502c37021415 . "./code.cg2js/cg-html-widget.fasl")
(#x02e6d1054e610b30fb20f54217d21e1e . "./code.cg2js/cg-selected-object.fasl")
(#x2eafc8eaf132da2e12fdebd8aff6f517 . "./code.cg2js/cg-lamp.fasl")
(#xd24bfc8294039f3913052fccd4e31c32 . "./code.cg2js/cg-scroll-bar.fasl")
(#xa14a8d68876442f53d843a25b10ef69c . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x23aa19c6b41e3fd1b528dfea7e6d14c5 . "./code.cg2js/cg-message-dialog.fasl")
(#x5f62a9703344d4109f7f9b473dfd4c03 . "./code.cg2js/cg-dde-utils.fasl")
(#x28194f85a78a348e23ac0302935441a9 . "./code.cg2js/cg-group-box.fasl")
(#x48586dbee55efa98338f097d6ddce7db . "./code.cg2js/cg-find-string-dialog.fasl")
(#x7c979e25597c1b89cf6e0a246d009b55 . "./code.cg2js/cg-split-bar.fasl")
(#x9d0adbac9ba2ff33d5fe7220eca6c190 . "./code.cg2js/cg-radio-button.fasl")
(#x96d2e258ad99cd3e1d224202aeb3687f . "./code.cg2js/cg-base.fasl")
(#xee0ccdc87c2cf138aeeb199ef268aa44 . "./code.cg2js/cg-paren-matching.fasl")
(#x6def657bacdddd56228e43b866a47ecb . "./code.cg2js/cg-graphics-context.fasl")
(#x0947733223e299f1d929113aeba3ae76 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#xb6f9b5f109ba3f24473abd11e73d917c . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x643ffd5301cad556892017db2fdbfbbd . "./code.cg2js/cg-plot-widget.fasl")
(#xcc8f8f6491bbb99283792fbdaec1f52e . "./code.cg2js/cg-dev.fasl")
(#x2ad544e05e39d72164f54baa275a23c4 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x20e430b851391dfa483ab24b27d04d56 . "./code.cg2js/cg-tab-control.fasl")
(#xdcaa8d261ee446e1c66a56dd5286dd4b . "./code.cg2js/cg-fill-texture.fasl")
(#x726149ebb919d268f2556c1685285429 . "./code.cg2js/cg-menu-tooltip.fasl")
(#x1aa212d97ce512d296f12faef5279594 . "./code.cg2js/cg-trackbar.fasl")
(#xd67e8976247da1badad43ed442b2515d . "./code.cg2js/cg-nodes.fasl")
(#xcf312c3ed2d0c8c811479209a6d0007e . "./code.cg2js/cg-common-control.fasl")
(#x8ae71c22dcf5f9aedcc7ef845356e1e7 . "./code.cg2js/cg-list-view.fasl")
(#xe082b66b0253676dc871c41d6c317fa6 . "./code.cg2js/cg-rich-edit.fasl")
(#x80a6294e71810d4894ce1e7ca8fbc2a0 . "./code.cg2js/cg-project-window.fasl")
(#xe39b34ea4647626655049d30eea9c1b8 . "./code.cg2js/cg-item-list.fasl")
(#xf2b203eaab816f2b90b0c66d7f911c56 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x4bb7f64c3ff9c929446155ec30766bd4 . "./code.cg2js/cg-get-position.fasl")
(#x37c318a73374e0867d23b05451a44431 . "./code.cg2js/cg-bitmap-pane.fasl")
(#xbc1ab27074ce49106b1be4f708e0dbd6 . "./code.cg2js/cg-drawable.fasl")
(#xe7cd936a2ccdebf0c2800c1ab8076c6e . "./code.cg2js/cg-lettered-menu.fasl")
(#xd8287734ffe687fb78342b54ea9712be . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x0884ccc11746feeb306d3eb5b23210f1 . "./code.cg2js/cg-html-dialog.fasl")
(#x6471b6aa102d9062745f0be2a76a4575 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x90e8430cb8be2a7428d733697cdaa3ca . "./code.cg2js/cg-utility-dialog.fasl")
(#x841b4c29bf22096d7e2f71356ea322b8 . "./code.cg2js/cg-pixmap-widget.fasl")
(#x73d4a62e5f2b9f5dd88c6f81ff98bc54 . "./code.cg2js/cg-property.fasl")
(#x4218e087a90b65f981ca907500e6d284 . "./code.cg2js/cg-menu.fasl")
(#x5f74a7428f617479248ecc69413c6545 . "./code.cg2js/cg-clipboard.fasl")
(#xbb673426d2bbea153327fb608c6973b3 . "./code.cg2js/cg-toggling-widget.fasl")
(#xaa9a6a1070f4d45d13388b249697f57c . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x07d616cf0131ddce8e649f3fed1d4347 . "./code.cg2js/cg-template-string.fasl")
(#xa8950ef034bfe09ed526ab679910bc07 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x6d47e0f1d14b60dfea23f4e37b05092d . "./code.cg2js/cg-os-window.fasl")
(#x14392d417afd8a3a33fa0cfe832099e2 . "./code.cg2js/cg-grid-widget.fasl")
(#x473e2440d14277618d2ca4c42ec539f2 . "./code.cg2js/cg-picture-widget.fasl")
(#xfa5f06b3da5aa75d21b3f61df7a57a00 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x333d6be5fe64f53144e5d76f8f9b4829 . "./code.cg2js/cg-static-text.fasl")
(#x3fc19826fe62d639336d74348a150587 . "./code.cg2js/cg-clipboard-stack.fasl")
(#x70fc15c8933d9abcef3ada7f523fa74f . "./code.cg2js/cg-text-widget.fasl")
(#x8f9a099d7ebce75c66551e4e6ff8b4b9 . "./code.cg2js/cg-calendar.fasl")
(#x7c2e45bd5381d21a7af24ecb47022218 . "./code.cg2js/cg-check-box.fasl")
(#x0fd0e132610512fc38ddd8581db5a4ac . "./code.cg2js/cg-acache.fasl")
(#x1ae5b24ae00b62fd66c90a67dd60dca9 . "./code.cg2js/cg-wrap-string.fasl")
(#x85d4dc215a14b3a9c031d3cf30e7afc9 . "./code.cg2js/cg-bitmap-stream.fasl")
(#xe65b67f16e6227eba98ffa56c9004e10 . "./code.cg2js/cg-font-dialog.fasl")
(#x1e7d5a5f45faf5eed96a4b967db4e234 . "./code.cg2js/cg-outline.fasl")
(#xca6fbbe850bc8e2d07997d69ce9ff6a2 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x29a744ca310ca22d28bcbfcc13750ef6 . "./code.cg2js/cg-status-bar.fasl")
(#x2ce11e790abe0f33ce89639789b096b7 . "./code.cg2js/cg-multi-picture-button.fasl")
(#xd0fa4ac31e7600cd3b003148671dc55b . "./code.cg2js/cg-hotspot.fasl")
(#x702521be8d81c434bce6c2a8cafc7f6c . "./code.cg2js/cg-scaling-stream.fasl")
(#x8929d78d3185770557f763c6d7c06943 . "./code.cg2js/cg-icon-pixmap.fasl")
(#x519e6139d5797e5857114695fa546179 . "./code.cg2js/cg-file-dialog.fasl")
(#xf8c30c303b2aabc844500fea47d0ecb7 . "./code.cg2js/cg-color-dialog.fasl")
(#x88144bfd0700d19d9277296631052edc . "./code.cg2js/cg-get-pixmap.fasl")
(#x8d34ed2b995be77059abdf4b648154aa . "./code.cg2js/cg-object-editor.fasl")
(#x5cfccc78f531db86c5cfeb3030d2ee94 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#xb463ee3c27cc52ad43a3d29ee63a6bd1 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xa7660eba340eaceaf6f8d7f791e52fa1 . "./code.cg2js/cg-pixmap.fasl")
(#x4487a7fb1e5e717b2396145d5190ec08 . "./code.cg2js/cg-intersect.fasl")
(#xcb2ed0a51be34417cb53b55851f78234 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x6321d261f668821d3cffec14005b6687 . "./code.cg2js/cg-icon.fasl")
(#xf6b62eac8901ff345bd60e34d4d28305 . "./code.cg2js/cg-yes-no-string.fasl")
(#x01f47baf4730802da0c4d92cb0af695e . "./code.cg2js/cg-text-or-combo.fasl")
(#x0f4b60391bda031e494b11c308ee86ca . "./code.cg2js/cg.fasl")
(#x2b2697c77de306388e3835a27c781723 . "./code.cg2js/cg-dialog-item.fasl")
(#x876c84142831edd8d3b7abf00cfcd953 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x0a7f3eccaeadf90508dbd97a803808b7 . "./code.cg2js/cg-caret.fasl")
(#x1ed5261b1c3c847fe98525398b07bce5 . "./code.cg2js/cg-editable-text.fasl")
(#xfc78ddd5b3d74127962fce7bdbe49fb2 . "./code.cg2js/cg-choose-printer.fasl")
(#x2376e4799731cda0cd92efd19f8d944a . "./code.cg2js/cg-yes-no-list.fasl")
(#xf2a5ce4f41d92ac834e10f2dc8cb1a0e . "./code.cg2js/cg-intersect-posbox.fasl")
(#x1eea6ecce61dd06f95b2f790e21bfc75 . "./code.cg2js/cg-tooltip.fasl")
(#xe75b73bf0f5790e79acc7d135c745d22 . "./code.cg2js/cg-class-slot-grid.fasl")
(#xfc172d2158e979b13e145011f1c80ea7 . "./code.cg2js/cg-combo-box.fasl")
(#x4402713676df1388de000329c80e8c64 . "./code.cg2js/cg-curve.fasl")
(#x46e710a704e08b16b92d7f1ed2455c3d . "./code.cg2js/cg-web-browser.fasl")
(#x598accedbfb8b6a1fe7777fb48399aeb . "./code.cg2js/cg-printing.fasl")
(#xd5c6224918af464f83568ef4e12416f3 . "./code.cg2js/cg-lisp-widget.fasl")
(#x5719b51f5a9497be6ac6b16eda7947c4 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x700385af587dc10815626354b6aa7916 . "./code.cg2js/cg-palette.fasl")
(#xe96ca58d02b27a9273a32c56a9df9cf1 . "./code.cg2js/cg-os-widget.fasl")
(#xd552f45412d3a2b61c4174d24466971e . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x2975196446cf2103db5f1d03bfedf950 . "./code.cg2js/cg-pixmap-printing.fasl")
(#x08d89f77690ea2ec4e7e7406a7fd9422 . "./code.cg2js/cg-button.fasl")
(#xf899c1445336b0ec1f30bc22c48e784c . "./code.cg2js/cg-edit-in-place.fasl")
(#x1ddc0a59bdb94bc7c2f07052e0acf729 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x82d406024656ddfc48305023ec140409 . "./code.cg2js/cg-comtab.fasl")
(#xbbb36743b2018e31ac17711c8306484b . "./code.cg2js/cg-string-dialog.fasl")
(#x411d28a8ebe934f9a0fb58bf292239c4 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x36b186cb630b986d7858ffac2aeb81d0 . "./code.cg2js/cg-up-down-control.fasl")
(#x75e79002fb8af948440c6cc28b02a0e2 . "./code.cg2js/cg-layout.fasl")
(#xa4b9169617c5b9a29a66df645edc5892 . "./code.cg2js/cg-chart-widget.fasl")
(#x9c209299188b221b175d018c4bdd8ada . "./code.cg2js/cg-lisp-text.fasl")
(#xedf9654c7da92f6e932593f13d0dd3e4 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x37a59369f0c71b252f0cbd1720cd2688 . "./code.cg2js/cg-progress-indicator.fasl")
(#xc46e13abfb2927c8e74f78184f81bc39 . "./code.idejs/ide-inspector.fasl")
(#x85a4faf80ef895d838cf003b333a14b9 . "./code.idejs/ide-grapher.fasl")
(#x539a369046144c5769848e5573930b13 . "./code.idejs/ide-base.fasl")
(#x27a9e8f8cb1a77ce88226593234f3cfe . "./code.idejs/ide-keyshort.fasl")
(#x2cac70c9a0177c0a6091999e64cdbb28 . "./code.idejs/ide-dev.fasl")
(#xb3a7f7bb4b223f3b1a6393468a66d2ea . "./code.idejs/ide-class-browser.fasl")
(#x8f7b995a8eee2f4bd727d749d11dae69 . "./code.idejs/ide-package-list.fasl")
(#x592d95007edacde4e75f55ac59bbbab0 . "./code.idejs/ide-intro.fasl")
(#xaa41900319fcf63be31658912e9f1d82 . "./code.idejs/ide-class-grapher.fasl")
(#xf00e8a997c13901911207738061e6567 . "./code.idejs/ide-window-list.fasl")
(#xba05b9340719f7510dbc26888a3d680b . "./code.idejs/ide-find-definitions.fasl")
(#x30649c4674aa1cb4e626ebfcf73f1d8d . "./code.idejs/ide-trace.fasl")
(#xe3ffc19d1e7a2a10f2eb3faae137befe . "./code.idejs/ide-editor.fasl")
(#x860ea99f41d065aebd43147b12334dda . "./code.idejs/ide-patch-dialog.fasl")
(#x658e1bb0eb4956b85c73448eb1ee01f3 . "./code.idejs/ide-project.fasl")
(#x305d8f1f4129ef400f2f9bc61eedc034 . "./code.idejs/ide.fasl")
(#x4c179490d37555f9b50023527cf3a983 . "./code.idejs/ide-apropos.fasl")
(#x6ef7f66a23eb1ade0917804e0b70e3ef . "./code.idejs/ide-acache.fasl")
(#xe9e6e3aafe951d06d8480554e2ed315b . "./code.idejs/ide-clipboard.fasl")
(#x225754689c51f9259eeb62a501c5bb72 . "./code.idejs/ide-process-browser.fasl")
(#xb17c42f60493c47fc4f1fd4e019d1369 . "./code.idejs/ide-find-in-files.fasl")
(#x9f497c8d697ff67cb8be4040f38c0d85 . "./code.idejs/ide-form.fasl")
(#x6a45979afe3e7d084c72cf35f32b6d04 . "./code.idejs/ide-navigator.fasl")
(#x696b64509ebe0538a3b58ac1081d4fa0 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
